@@ -29,6 +29,7 @@ OC.L10N.register(
     "Signature" : "Llofnod",
     "Mail server" : "Gweinydd e-bost",
     "Go back" : "Nôl",
+    "Email address" : "Cyfeiriad e-bost",
     "Cancel" : "Diddymu",
     "Add mail account" : "Ychwanegu cyfrif post",
     "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "Report this bug" : "Cofnodi'r gwall",
     "All day" : "Drwy'r dydd",
     "Create" : "Creu",
+    "Comment" : "Sylw",
     "Accept" : "Derbyn",
     "Decline" : "Gwrthod",
     "Choose" : "Dewisa",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Untitled event" : "Digwyddiad di-deitl",
     "General" : "Cyffredinol",
     "User" : "User",
+    "Certificate" : "Tystysgrif",
     "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "Speed up your Mail experience with these quick shortcuts." : "Cyflymwch eich profiad E-bost gyda'r llwybrau byr cyflym hyn.",
     "Compose new message" : "Ysgrifennu Neges _Newydd",
