@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Đã đính kèm tin nhắn %s",
     "Important mail" : "Thư quan trọng",
+    "No message found yet" : "Không có tin nhắn nào được tìm thấy",
+    "Set up an account" : "Thiết lập một tài khoản",
     "Unread mail" : "Thư chưa đọc",
     "Important" : "Quan trọng",
     "Work" : "Công việc",
@@ -71,6 +73,7 @@ OC.L10N.register(
     "Enable formatting" : "Bật định dạng",
     "Request a read receipt" : "Yêu cầu xác nhận đã đọc",
     "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
+    "Enter a date" : "Nhập ngày",
     "Add share link from {productName} Files" : "Thêm liên kết chia sẻ từ Tệp {productName}",
     "Send" : "Gởi",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
@@ -78,8 +81,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Các tệp đính kèm vượt quá kích thước được cho phép là {size}. Thay vào đó, hãy chia sẻ các tệp qua liên kết."],
     "Confirm" : "Xác nhận",
-    "No message found yet" : "Không có tin nhắn nào được tìm thấy",
-    "Set up an account" : "Thiết lập một tài khoản",
     "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
     "No messages" : "Không có tin nhắn",
     "Draft: " : "Bản nháp: ",
@@ -128,7 +129,6 @@ OC.L10N.register(
     "Reply to sender only" : "Chỉ trả lời người gửi",
     "View source" : "Xem nguồn",
     "Download thread data for debugging" : "Tải xuống dữ liệu chuỗi để gỡ lỗi",
-    "Message source" : "Nguồn tin nhắn",
     "Message body" : "Nội dung thư",
     "Import into calendar" : "Nhập vào lịch",
     "Download attachment" : "Tải xuống Tệp đính kèm",
@@ -189,9 +189,11 @@ OC.L10N.register(
     "Contacts with this address" : "Liên hệ với địa chỉ này",
     "Add to Contact" : "Thêm liên hệ",
     "New Contact" : "ĐỊa chỉ liên hệ mới",
+    "Copy to clipboard" : "Sao chép vào clipboard",
     "Contact name …" : "Tên người liên hệ …",
     "Add" : "Thêm",
     "Close" : "Đóng",
+    "Body" : "Thân",
     "Tags" : "Nhãn",
     "Select tags" : "Chọn một thẻ",
     "Clear" : "Xóa",
@@ -216,6 +218,7 @@ OC.L10N.register(
     "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
     "Mark as unread" : "Đánh dấu là chưa đọc",
     "Mark as read" : "Đánh dấu đã đọc",
+    "Message source" : "Nguồn tin nhắn",
     "Remove" : "Xóa",
     "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
