@@ -80,7 +80,7 @@ class CollectedAddressMapper extends QBMapper {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select($qb->func()->count())
 			->from($this->getTableName());
-		$result = $qb->execute();
+		$result = $qb->executeQuery();
 
 		$count = (int)$result->fetchColumn();
 		$result->closeCursor();
@@ -115,7 +115,7 @@ class CollectedAddressMapper extends QBMapper {
 			->from($this->getTableName(), 'c')
 			->leftJoin('c', 'mail_accounts', 'a', $qb1->expr()->eq('c.user_id', 'a.user_id'))
 			->where($qb1->expr()->isNull('a.id'));
-		$result = $idsQuery->execute();
+		$result = $idsQuery->executeQuery();
 		$ids = array_map(static function (array $row) {
 			return (int)$row['id'];
 		}, $result->fetchAll());
@@ -127,7 +127,7 @@ class CollectedAddressMapper extends QBMapper {
 			->where($qb2->expr()->in('id', $qb2->createParameter('ids')));
 		foreach (array_chunk($ids, 1000) as $chunk) {
 			$query->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
-			$query->execute();
+			$query->executeStatement();
 		}
 	}
 }
